@@ -390,12 +390,14 @@ class SpotifyPrivate(SpotifyCredential):
         Returns:
             DataFrame com os dados da request
         """
-        decompressed_response = gzip.decompress(request.content)
-        my_json = decompressed_response.decode('utf-8')
-        my_json = f'[{my_json}]'
-        my_json = my_json.replace('\n', '')
-        my_json = my_json.replace('}{', '},{')
-        return json.loads(my_json)
+        # decompressed_response = gzip.decompress(request.content)
+        # my_json = decompressed_response.decode('utf-8')
+        # my_json = f'[{my_json}]'
+        # my_json = my_json.replace('\n', '')
+        # my_json = my_json.replace('}{', '},{')
+        # return json.loads(my_json)
+        data = request.json()
+        return pd.DataFrame(data)
 
     def get_tracks(self) -> pd.DataFrame:
         """
